<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [kibana-plugin-core-server](./kibana-plugin-core-server.md) &gt; [kibanaResponseFactory](./kibana-plugin-core-server.kibanaresponsefactory.md)

## kibanaResponseFactory variable

Set of helpers used to create `KibanaResponse` to form HTTP response on an incoming request. Should be returned as a result of [RequestHandler](./kibana-plugin-core-server.requesthandler.md) execution.

<b>Signature:</b>

```typescript
kibanaResponseFactory: {
    custom: <T extends string | Error | Buffer | Stream | Record<string, any> | {
        message: string | Error;
        attributes?: Record<string, any> | undefined;
    } | undefined>(options: CustomHttpResponseOptions<T>) => KibanaResponse<T>;
    badRequest: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    unauthorized: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    forbidden: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    notFound: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    conflict: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    internalError: (options?: ErrorHttpResponseOptions) => KibanaResponse<ResponseError>;
    customError: (options: CustomHttpResponseOptions<ResponseError>) => KibanaResponse<ResponseError>;
    redirected: (options: RedirectResponseOptions) => KibanaResponse<string | Buffer | Stream | Record<string, any>>;
    ok: (options?: HttpResponseOptions) => KibanaResponse<string | Buffer | Stream | Record<string, any>>;
    accepted: (options?: HttpResponseOptions) => KibanaResponse<string | Buffer | Stream | Record<string, any>>;
    noContent: (options?: HttpResponseOptions) => KibanaResponse<undefined>;
}
```

## Example

1. Successful response. Supported types of response body are: - `undefined`<!-- -->, no content to send. - `string`<!-- -->, send text - `JSON`<!-- -->, send JSON object, HTTP server will throw if given object is not valid (has circular references, for example) - `Stream` send data stream - `Buffer` send binary stream

```js
return response.ok();
return response.ok({ body: 'ack' });
return response.ok({ body: { id: '1' } });
return response.ok({ body: Buffer.from(...) });

const stream = new Stream.PassThrough();
fs.createReadStream('./file').pipe(stream);
return res.ok({ body: stream });

```
HTTP headers are configurable via response factory parameter `options` [HttpResponseOptions](./kibana-plugin-core-server.httpresponseoptions.md)<!-- -->.

```js
return response.ok({
  body: { id: '1' },
  headers: {
    'content-type': 'application/json'
  }
});

```
2. Redirection response. Redirection URL is configures via 'Location' header.

```js
return response.redirected({
  body: 'The document has moved',
  headers: {
   location: '/new-url',
  },
});

```
3. Error response. You may pass an error message to the client, where error message can be: - `string` send message text - `Error` send the message text of given Error object. - `{ message: string | Error, attributes: {data: Record<string, any>, ...} }` - send message text and attach additional error data.

```js
return response.unauthorized({
  body: 'User has no access to the requested resource.',
  headers: {
    'WWW-Authenticate': 'challenge',
  }
})
return response.badRequest();
return response.badRequest({ body: 'validation error' });

try {
  // ...
} catch(error){
  return response.badRequest({ body: error });
}

return response.badRequest({
 body:{
   message: 'validation error',
   attributes: {
     requestBody: request.body,
     failedFields: validationResult
   }
 }
});

try {
  // ...
} catch(error) {
  return response.badRequest({
    body: error
  });
}


```
4. Custom response. `ResponseFactory` may not cover your use case, so you can use the `custom` function to customize the response.

```js
return response.custom({
  body: 'ok',
  statusCode: 201,
  headers: {
    location: '/created-url'
  }
})

```

